@@ -8,7 +8,7 @@ import github
 
 
 def synchronize(
-    manifest: str,
+    manifest: str = None,
     token: str = None,
     repository: str = "synchronization-demo-public",
     organization: str = "pyansys",
@@ -29,6 +29,7 @@ def synchronize(
 
     user_name = os.environ.get("BOT_NAME")
     user_email = os.environ.get("BOT_EMAIL")
+
     branch_name = "sync/sync_branch"
     origin_directory = os.path.join(os.getcwd())
 
@@ -69,6 +70,8 @@ def synchronize(
                 stderr=subprocess.PIPE,
             )
             stdout, stderr = process.communicate()
+            print(stdout)
+            print(stderr)
         except:
             process = subprocess.Popen(
                 ["git", "checkout", branch_name],
@@ -76,17 +79,27 @@ def synchronize(
                 stderr=subprocess.PIPE,
             )
             stdout, stderr = process.communicate()
+            print(stdout)
+            print(stderr)
 
         # Read manifest
-        with open(manifest, "r") as f:
-            prohibited_extensions = f.read().splitlines()
+        if manifest:
+            with open(manifest, "r") as f:
+                prohibited_extensions = f.read().splitlines()
 
-        # Add protos.
-        shutil.copytree(
-            os.path.join(origin_directory, protos_path),
-            os.path.join(os.getcwd(), protos_path),
-            ignore=shutil.ignore_patterns(*prohibited_extensions),
-        )
+                # Add protos.
+                shutil.copytree(
+                    os.path.join(origin_directory, protos_path),
+                    os.path.join(os.getcwd(), protos_path),
+                    ignore=shutil.ignore_patterns(*prohibited_extensions),
+                )
+
+        else:
+            # Add protos.
+            shutil.copytree(
+                os.path.join(origin_directory, protos_path),
+                os.path.join(os.getcwd(), protos_path),
+            )
 
         # unsafe, should add specific file or directory
         process = subprocess.Popen(
@@ -95,6 +108,8 @@ def synchronize(
             stderr=subprocess.PIPE,
         )
         stdout, stderr = process.communicate()
+        print(stdout)
+        print(stderr)
 
         if protos_path:
             message = f"""Add folder content from {protos_path}."""
@@ -117,6 +132,8 @@ def synchronize(
                 stderr=subprocess.PIPE,
             )
             stdout, stderr = process.communicate()
+            print(stdout)
+            print(stderr)
 
             process = subprocess.Popen(
                 ["git", "push", "-u", "origin", branch_name],
@@ -124,6 +141,8 @@ def synchronize(
                 stderr=subprocess.PIPE,
             )
             stdout, stderr = process.communicate()
+            print(stdout)
+            print(stderr)
 
             # Create pull request.
             gh = github.Github(token)
